#!/bin/csh

# Check to see if test case directory was passed
if ( $1 == "-h" ) then
  echo "To generate timeseries plots, this script can be passed a directory"
  echo "containing a logs/ subdirectory, or it can be run in the directory with"
  echo "the log files, without being passed a directory."
  echo "Example: ./timeseries.csh ./annual_gx3_conrad_4x1.t00"
  echo "Example: ./timeseries.csh"
  echo "It will pull the diagnostic data from the most recently modified log file."
  exit -1
endif
set basename = `echo $1 | sed -e 's#/$##' | sed -e 's/^\.\///'`

# Set x-axis limits
  # Manually set x-axis limits
#set xrange = 'set xrange ["19980101":"19981231"]'
  # Let gnuplot determine x-axis limits
set xrange = ''

# Determine if BASELINE dataset exists
if ( $1 == "" ) then
set basefile_dir = "IGNORE"
else
source $1/cice.settings
set basefile_dir = "$ICE_BASELINE/$ICE_BASECOM/$ICE_TESTNAME"
endif

if ( -d $basefile_dir ) then
  set num_basefile = `ls $basefile_dir | grep cice.runlog | wc -l`
  if ( $num_basefile > 0 ) then
    set baseline_exists = 1
    foreach file ($basefile_dir/cice.runlog.*)
      set base_logfile = $file
    end
  else
    set baseline_exists = 0
  endif
else
  set baseline_exists = 0
endif

set fieldlist=("total ice area  (km^2)" \
               "total ice extent(km^2)" \
               "total ice volume (m^3)" \
               "total snw volume (m^3)" \
               "rms ice speed    (m/s)" \
               "average albedo        " \
               "max ice volume     (m)" \
               "max ice speed    (m/s)" \
               "max strength    (kN/m)" \
               "arwt rain h2o kg in dt" \
               "arwt snow h2o kg in dt" \
               "arwt evap h2o kg in dt" \
               "arwt frzl h2o kg in dt" \
               "arwt frsh h2o kg in dt" \
               "arwt ice mass (kg)    " \
               "arwt snw mass (kg)    " \
               "arwt tot mass (kg)    " \
               "arwt tot mass chng(kg)" \
               "arwt water flux       " \
               "water flux error      " \
               "arwt atm heat flux (W)" \
               "arwt ocn heat flux (W)" \
               "arwt frzl heat flux(W)" \
               "arwt tot energy    (J)" \
               "arwt net heat      (J)" \
               "arwt tot energy chng(J)" \
               "arwt heat error       " \
               "arwt incoming sw (W)  " \
               "arwt absorbed sw (W)  " \
               "arwt swdn error       " \
               "total brine tr (m^3)  " \
               "arwt salt mass (kg)   " \
               "arwt salt mass chng(kg)" \
               "arwt salt flx in dt(kg)" \
               "arwt salt flx error   " \
               "air temperature (C)   " \
               "specific humidity     " \
               "snowfall (m)          " \
               "rainfall (m)          " \
               "shortwave radiation sum" \
               "longwave radiation    " \
               "area fraction         " \
               "avg ice thickness (m) " \
               "avg snow depth (m)    " \
               "avg salinity (ppt)    " \
               "avg brine thickness (m)" \
               "surface temperature(C)" \
               "absorbed shortwave flx" \
               "outward longwave flx  " \
               "sensible heat flx     " \
               "latent heat flx       " \
               "subl/cond (m ice)     " \
               "top melt (m)          " \
               "bottom melt (m)       " \
               "lateral melt (m)      " \
               "new ice (m)           " \
               "congelation (m)       " \
               "snow-ice (m)          " \
               "snow change (m)       " \
               "effective dhi (m)     " \
               "effective dhs (m)     " \
               "intnl enrgy chng(W/m^2)" \
               "sst (C)               " \
               "sss (ppt)             " \
               "freezing temp (C)     " \
               "heat used (W/m^2)     " )

# Get the filename for the latest log
if ( $1 == "" ) then
foreach file (./cice.runlog.*)
  set logfile = $file
end
else
foreach file ($1/logs/cice.runlog.*)
  set logfile = $file
end
endif

# Loop through each field and create the plot
foreach field ($fieldlist:q)
  set fieldname = `echo "$field" | sed -e 's/([^()]*)//g'`
  set search = "'$fieldname'\|istep1"
  rm -f data.txt
  foreach line ("`egrep $search $logfile`")
    if ("$line" =~ *"istep1"*) then
      set argv = ( $line )
      set date = $4
      @ hour = ( $6 / 3600 )
    else
      set data1 = `echo $line | rev | cut -d ' ' -f2 | rev`
      set data2 = `echo $line | rev | cut -d ' ' -f1 | rev`
      echo "$date-$hour,$data1,$data2" >> data.txt
    endif
  end
  set format = "%Y%m%d-%H"

  set output = `echo $fieldname | sed 's/ /_/g'`
  set output = "${output}_${ICE_CASENAME}.png"

  echo "Plotting data for '$fieldname' and saving to $output"

# Call the plotting routine, which uses the data in the data.txt file
gnuplot << EOF > $output
# Plot style
set style data points

set datafile separator ","

# Term type and background color, canvas size
set terminal png size 1920,960

# x-axis 
set xdata time
set timefmt "$format"
set format x "%Y/%m/%d"

# Axis tick marks
set xtics rotate

set title "$field (Diagnostic Output)" 
set ylabel "$field" 
set xlabel "Simulation Day" 

set key left top

# Set x-axlis limits
$xrange

if ( $baseline_exists == 1 ) \
  plot "data_baseline.txt" using (timecolumn(1)):2 with lines  lw 2 lt 2 lc 2 title \
       "Arctic - Baseline", \
       "" using (timecolumn(1)):3 with lines lw 2 lt 2 lc 5 title "Antarctic - Baseline", \
       "data.txt" using (timecolumn(1)):2 with lines lw 2 lt 1 lc 1 title "Arctic", \
       "" using (timecolumn(1)):3 with lines lw 2 lt 1 lc 3 title "Antarctic"; \
else \
  plot "data.txt" using (timecolumn(1)):2 with lines lw 2 lt 1 lc 1 title "Arctic", \
       "" using (timecolumn(1)):3 with lines lw 2 lt 1 lc 3 title "Antarctic" \
  
EOF

# Delete the data file
rm -f data.txt
if ( $baseline_exists ) then
  rm -f data_baseline.txt
endif
end
